@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
@@ -24,13 +23,10 @@ References
 - HepPDT and HepPID versions 3.04.01.
 """
 
-from __future__ import absolute_import, division, print_function
 
 from enum import IntEnum
 from typing import Optional, SupportsInt
 
-from deprecated import deprecated as _deprecated
-
 PDGID_TYPE = SupportsInt
 
 
@@ -51,8 +47,7 @@ class Location(IntEnum):
     N10 = 10
 
 
-def is_valid(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_valid(pdgid: PDGID_TYPE) -> bool:
     """Is it a valid PDG ID?"""
     if _fundamental_id(pdgid) != 0:  # function always returns a number >= 0
         return True
@@ -85,14 +80,12 @@ def is_valid(pdgid):
     return False
 
 
-def abspid(pdgid):
-    # type: (PDGID_TYPE) -> int
+def abspid(pdgid: PDGID_TYPE) -> int:
     """Returns the absolute value of the PDG ID."""
     return abs(int(pdgid))
 
 
-def is_quark(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_quark(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a quark?
 
@@ -104,8 +97,7 @@ def is_quark(pdgid):
     return 1 <= abspid(pdgid) <= 8
 
 
-def is_sm_quark(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_sm_quark(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a Standard Model quark?
 
@@ -118,8 +110,7 @@ def is_sm_quark(pdgid):
     return 1 <= abspid(pdgid) <= 6
 
 
-def is_lepton(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_lepton(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a lepton?
 
@@ -131,8 +122,7 @@ def is_lepton(pdgid):
     return 11 <= abspid(pdgid) <= 18
 
 
-def is_sm_lepton(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_sm_lepton(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a Standard Model lepton?
 
@@ -145,8 +135,7 @@ def is_sm_lepton(pdgid):
     return 11 <= abspid(pdgid) <= 16
 
 
-def is_hadron(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_hadron(pdgid: PDGID_TYPE) -> bool:
     """Does this PDG ID correspond to a hadron?"""
     # Special case of proton and neutron:
     # needs to be checked first since _extra_bits(pdgid) > 0 for nuclei
@@ -163,8 +152,7 @@ def is_hadron(pdgid):
     return bool(is_Rhadron(pdgid))
 
 
-def is_meson(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_meson(pdgid: PDGID_TYPE) -> bool:
     """Does this PDG ID correspond to a meson?"""
     if _extra_bits(pdgid) > 0:
         return False
@@ -196,8 +184,7 @@ def is_meson(pdgid):
     return False
 
 
-def is_baryon(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_baryon(pdgid: PDGID_TYPE) -> bool:
     """Does this PDG ID correspond to a baryon?"""
     if abspid(pdgid) <= 100:
         return False
@@ -224,8 +211,7 @@ def is_baryon(pdgid):
     )
 
 
-def is_diquark(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_diquark(pdgid: PDGID_TYPE) -> bool:
     """Does this PDG ID correspond to a diquark?"""
     if _extra_bits(pdgid) > 0:
         return False
@@ -241,8 +227,7 @@ def is_diquark(pdgid):
     )
 
 
-def is_nucleus(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_nucleus(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a nucleus?
 
@@ -269,8 +254,7 @@ def is_nucleus(pdgid):
     return False
 
 
-def is_pentaquark(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_pentaquark(pdgid: PDGID_TYPE) -> bool:
     """
     Does the PDG ID correspond to a pentaquark?
 
@@ -301,8 +285,7 @@ def is_pentaquark(pdgid):
     return _digit(pdgid, Location.Nl) <= _digit(pdgid, Location.Nr)
 
 
-def is_gauge_boson_or_higgs(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_gauge_boson_or_higgs(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a gauge boson or a Higgs?
 
@@ -313,8 +296,7 @@ def is_gauge_boson_or_higgs(pdgid):
     return 21 <= abspid(pdgid) <= 40
 
 
-def is_sm_gauge_boson_or_higgs(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_sm_gauge_boson_or_higgs(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a Standard Model gauge boson or Higgs?
 
@@ -327,8 +309,7 @@ def is_sm_gauge_boson_or_higgs(pdgid):
     return 21 <= int(pdgid) <= 25
 
 
-def is_generator_specific(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_generator_specific(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to generator-specific pseudoparticles or concepts?
 
@@ -357,8 +338,7 @@ def is_generator_specific(pdgid):
     return False
 
 
-def is_special_particle(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_special_particle(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a special particle?
 
@@ -371,8 +351,7 @@ def is_special_particle(pdgid):
     )
 
 
-def is_Rhadron(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_Rhadron(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to an R-hadron?
 
@@ -396,8 +375,7 @@ def is_Rhadron(pdgid):
     )
 
 
-def is_Qball(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_Qball(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a Q-ball or any exotic particle with electric charge beyond the qqq scheme?
 
@@ -414,8 +392,7 @@ def is_Qball(pdgid):
     return _digit(pdgid, Location.Nj) == 0
 
 
-def is_dyon(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_dyon(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a Dyon, a magnetic monopole?
 
@@ -440,8 +417,7 @@ def is_dyon(pdgid):
     return _digit(pdgid, Location.Nj) == 0
 
 
-def is_SUSY(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_SUSY(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a SUSY particle?
 
@@ -456,8 +432,7 @@ def is_SUSY(pdgid):
     return _fundamental_id(pdgid) != 0
 
 
-def is_technicolor(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_technicolor(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to a Technicolor state?
 
@@ -468,8 +443,7 @@ def is_technicolor(pdgid):
     return _digit(pdgid, Location.N) == 3
 
 
-def is_excited_quark_or_lepton(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def is_excited_quark_or_lepton(pdgid: PDGID_TYPE) -> bool:
     """
     Does this PDG ID correspond to an excited (composite) quark or lepton?
 
@@ -482,58 +456,37 @@ def is_excited_quark_or_lepton(pdgid):
     return _digit(pdgid, Location.N) == 4 and _digit(pdgid, Location.Nr) == 0
 
 
-@_deprecated(
-    version="0.16.0",
-    reason="This method will be removed from version 0.17.0. Use is_excited_quark_or_lepton instead.",
-)
-def is_composite_quark_or_lepton(pdgid):
-    # type: (PDGID_TYPE) -> bool
-    """
-    Does this PDG ID correspond to an excited (composite) quark or lepton?
-
-    Excited (composite) quarks and leptons have N = 4 and Nr = 0.
-    """
-    return is_excited_quark_or_lepton(pdgid)
-
-
-def has_down(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_down(pdgid: PDGID_TYPE) -> bool:
     """Does this particle contain a down quark?"""
     return _has_quark_q(pdgid, 1)
 
 
-def has_up(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_up(pdgid: PDGID_TYPE) -> bool:
     """Does this particle contain an up quark?"""
     return _has_quark_q(pdgid, 2)
 
 
-def has_strange(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_strange(pdgid: PDGID_TYPE) -> bool:
     """Does this particle contain a strange quark?"""
     return _has_quark_q(pdgid, 3)
 
 
-def has_charm(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_charm(pdgid: PDGID_TYPE) -> bool:
     """Does this particle contain a charm quark?"""
     return _has_quark_q(pdgid, 4)
 
 
-def has_bottom(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_bottom(pdgid: PDGID_TYPE) -> bool:
     """Does this particle contain a bottom quark?"""
     return _has_quark_q(pdgid, 5)
 
 
-def has_top(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_top(pdgid: PDGID_TYPE) -> bool:
     """Does this particle contain a top quark?"""
     return _has_quark_q(pdgid, 6)
 
 
-def has_fundamental_anti(pdgid):
-    # type: (PDGID_TYPE) -> bool
+def has_fundamental_anti(pdgid: PDGID_TYPE) -> bool:
     """
     If this is a fundamental particle, does it have a valid antiparticle?
 
@@ -559,8 +512,7 @@ def has_fundamental_anti(pdgid):
     return False
 
 
-def charge(pdgid):
-    # type: (PDGID_TYPE) -> Optional[float]
+def charge(pdgid: PDGID_TYPE) -> Optional[float]:
     """Returns the charge."""
 
     three_charge_pdgid = three_charge(pdgid)
@@ -572,8 +524,7 @@ def charge(pdgid):
         return three_charge_pdgid / 30.0
 
 
-def three_charge(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def three_charge(pdgid: PDGID_TYPE) -> Optional[int]:
     """
     Returns 3 times the charge.
 
@@ -733,8 +684,7 @@ def three_charge(pdgid):
     return charge
 
 
-def j_spin(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def j_spin(pdgid: PDGID_TYPE) -> Optional[int]:
     """Returns the total spin as 2J+1."""
     if not is_valid(pdgid):
         return None
@@ -758,17 +708,13 @@ def j_spin(pdgid):
     return abspid(pdgid) % 10
 
 
-def J(pdgid):
-    # type: (PDGID_TYPE) -> Optional[float]
+def J(pdgid: PDGID_TYPE) -> Optional[float]:
     """Returns the total spin J."""
     value = j_spin(pdgid)
-    return (
-        (value - 1) / 2 if value is not None else value
-    )  # This works due to the Python 3 style division
+    return (value - 1) / 2 if value is not None else value
 
 
-def S(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def S(pdgid: PDGID_TYPE) -> Optional[int]:
     """
     Returns the spin S.
 
@@ -803,8 +749,7 @@ def S(pdgid):
         return 0
 
 
-def s_spin(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def s_spin(pdgid: PDGID_TYPE) -> Optional[int]:
     """
     Returns the spin S as 2S+1.
 
@@ -818,8 +763,7 @@ def s_spin(pdgid):
     return (2 * value + 1) if value is not None else value
 
 
-def L(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def L(pdgid: PDGID_TYPE) -> Optional[int]:
     """
     Returns the orbital angular momentum L.
 
@@ -881,8 +825,7 @@ def L(pdgid):
     return 0
 
 
-def l_spin(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def l_spin(pdgid: PDGID_TYPE) -> Optional[int]:
     """
     Returns the orbital angular momentum L as 2L+1.
 
@@ -896,8 +839,7 @@ def l_spin(pdgid):
     return (2 * value + 1) if value is not None else value
 
 
-def A(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def A(pdgid: PDGID_TYPE) -> Optional[int]:
     """Returns the atomic number A if the PDG ID corresponds to a nucleus. Else it returns None."""
     # A proton can be a Hydrogen nucleus
     # A neutron can be considered as a nucleus when given the PDG ID 1000000010,
@@ -909,8 +851,7 @@ def A(pdgid):
     return (abspid(pdgid) // 10) % 1000
 
 
-def Z(pdgid):
-    # type: (PDGID_TYPE) -> Optional[int]
+def Z(pdgid: PDGID_TYPE) -> Optional[int]:
     """Returns the charge Z if the PDG ID corresponds to a nucleus. Else it returns None."""
     # A proton can be a Hydrogen nucleus
     if abspid(pdgid) == 2212:
@@ -924,8 +865,7 @@ def Z(pdgid):
     return ((abspid(pdgid) // 10000) % 1000) * (int(pdgid) // abs(int(pdgid)))
 
 
-def _digit(pdgid, loc):
-    # type: (PDGID_TYPE, int) -> int
+def _digit(pdgid: PDGID_TYPE, loc: int) -> int:
     """
     Provides a convenient index into the PDGID number, whose format is in base 10.
 
@@ -935,16 +875,14 @@ def _digit(pdgid, loc):
     return int(sid[-loc]) if loc <= len(sid) else 0
 
 
-def _extra_bits(pdgid):
-    # type: (PDGID_TYPE) -> int
+def _extra_bits(pdgid: PDGID_TYPE) -> int:
     """
     Returns everything beyond the 7th digit, so anything outside the PDG numbering scheme.
     """
     return abspid(pdgid) // 10000000
 
 
-def _fundamental_id(pdgid):
-    # type: (PDGID_TYPE) -> int
+def _fundamental_id(pdgid: PDGID_TYPE) -> int:
     """
     Returns the first 2 digits if this is a "fundamental" particle.
     Returns 0 if the particle is not fundamental or not standard (PDG ID with more than 7 digits).
@@ -965,8 +903,7 @@ def _fundamental_id(pdgid):
         return 0
 
 
-def _has_quark_q(pdgid, q):
-    # type: (PDGID_TYPE, int) -> bool
+def _has_quark_q(pdgid: PDGID_TYPE, q: int) -> bool:
     """
     Helper function - does this particle contain a quark q?
 
